==> ec2init-0.11-py3-none-any.whl: ec2init/plans/init/configure_glassfish.py <==
import logging
import pathlib
import shutil
from pathlib import Path

from configparser import ConfigParser

from typing import Any
from typing import Dict
from typing import List

from ec2init import Procedure
from ec2init.utils.system import SystemUtils

logger = logging.getLogger(__name__)

class ConfigureGlassfish(Procedure):
    GLASSFISH_START_TIMEOUT = 900
    def __init__(self, name: str, config: ConfigParser, ldap_conf: Dict[str, Any], check_file: Path, has_configured_glassfish: bool) -> None:
        self.name = name
        self.config = config
        self.ldap_conf = ldap_conf
        self.check_file = check_file
        self.has_configured_glassfish = has_configured_glassfish

    def pre(self) -> None:
        if self.report_callback is not None:
            try:
                self.report_callback.execute()
            except Exception as ex:
                logger.warning("%s - Could not execute pre-execute: %s", self.name, ex)

    def ldap_command(self, conf: Dict[str, Any], user: str, password_file: str) -> List[str]:
        command = [
            "/srv/hops/glassfish/versions/current/bin/asadmin",
            "-I", "false",
            "-u", user,
            "--passwordfile", password_file,
            "create-jndi-resource",
            "--restype", "javax.naming.ldap.LdapContext",
            "--factoryclass", "com.sun.jndi.ldap.LdapCtxFactory",
            "--jndilookupname", conf['jndiLookupName']
        ]
        if conf['properties']:
            props = []
            for p in conf['properties']:
                props.append("%s=%s" % (p['name'], p['value'].replace(':', '\\:').replace('=', '\\=')))
            command.append("--property")
            command.append(":".join(props))
        command.append("ldap/LdapResource")
        return command

    def ldap_resource_created(self, user: str, password_file: str):
        command = [
            "/srv/hops/glassfish/versions/current/bin/asadmin",
            "-I", "false",
            "-u", user,
            "--passwordfile", password_file,
            "list-jndi-resources"
        ]
        output = SystemUtils.execute_command(command, check=False)
        return output.returncode == 0 and b"ldap/LdapResource" in output.stdout

    def _enable_start_glassfish(self):
        SystemUtils.execute_command(["systemctl", "enable", "glassfish-domain1"])
        SystemUtils.execute_command(["systemctl", "start", "glassfish-domain1"],
                timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

    def execute(self) -> List[Procedure]:
        if not self.has_configured_glassfish:
            # If it's unmanaged just enable and start glassfish
            if self.config.getboolean('general', 'unmanaged', fallback=False):
                self._enable_start_glassfish()
                return []

            if self.config.getboolean('general', 'issue_lets_encrypt'):
                installation_dir = self.config.get('general', 'installation_dir', fallback='/root/ec2init')
                configure_script = pathlib.Path(installation_dir, 'deploy2glassfish_hook.sh')
                logger.info("%s - Initial configuring Glassfish with Let's Encrypt certificate", self.name)
                # Increased timeout as it restarts Glassfish
                SystemUtils.execute_command(["/bin/bash", str(configure_script)],
                    timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

                # Copy script to Let's Encrypt deploy hooks
                lets_encrypt_dir = self.config.get('initplan', 'lets_encrypt_dir', fallback="/etc/letsencrypt")
                deploy_hooks = pathlib.Path(lets_encrypt_dir, 'renewal-hooks', 'deploy')
                logger.info("%s - Copying %s to %s", self.name, configure_script, deploy_hooks)
                shutil.copy(configure_script, deploy_hooks)
            else:
                self._enable_start_glassfish()

        # Configure LDAP if required
        # Note: asadmin requires Glassfish to run and modifying the domain.xml directly is not supported
        if self.ldap_conf and not self.ldap_resource_created("adminuser", "/srv/hops/domains/domain1_admin_passwd"):
            logger.info("Configuring LDAP: %s", self.ldap_conf['jndiLookupName'])
            command = self.ldap_command(self.ldap_conf, "adminuser", "/srv/hops/domains/domain1_admin_passwd")
            output = SystemUtils.execute_command(command, check=False)
            if output.returncode > 0:
                self.friendly_name = "Configure LDAP. Caused by " + output.stdout.decode("utf-8")
                raise Exception(self.friendly_name)
            SystemUtils.execute_command(["systemctl", "restart", "glassfish-domain1"],
                timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

        if self.check_file:
            self.check_file.touch()
        
        return []

    def rollback(self) -> None:
        pass

==> ec2init-0.19.2-py3-none-any.whl: ec2init/plans/init/configure_glassfish.py <==
import logging
import pathlib
import shutil
from pathlib import Path

from configparser import ConfigParser

from typing import Any
from typing import Dict
from typing import List

from ec2init import Procedure
from ec2init.utils.glassfish_asadmin import AsadminUtils
from ec2init.utils.system import SystemUtils

logger = logging.getLogger(__name__)

class ConfigureGlassfish(Procedure):
    GLASSFISH_START_TIMEOUT = 900
    def __init__(self, name: str, config: ConfigParser, ldap_conf: Dict[str, Any], check_file: Path, has_configured_glassfish: bool) -> None:
        self.name = name
        self.config = config
        self.ldap_conf = ldap_conf
        self.check_file = check_file
        self.has_configured_glassfish = has_configured_glassfish

    def pre(self) -> None:
        if self.report_callback is not None:
            try:
                self.report_callback.execute()
            except Exception as ex:
                logger.warning("%s - Could not execute pre-execute: %s", self.name, ex)

    def _enable_start_glassfish(self):
        SystemUtils.execute_command(["systemctl", "enable", "glassfish-domain1"])
        SystemUtils.execute_command(["systemctl", "start", "glassfish-domain1"],
                timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

    def execute(self) -> List[Procedure]:
        if not self.has_configured_glassfish:
            # If it's unmanaged just enable and start glassfish
            if self.config.getboolean('general', 'unmanaged', fallback=False):
                self._enable_start_glassfish()
                return []

            if self.config.getboolean('general', 'issue_lets_encrypt'):
                installation_dir = self.config.get('general', 'installation_dir', fallback='/root/ec2init')
                configure_script = pathlib.Path(installation_dir, 'deploy2glassfish_hook.sh')
                logger.info("%s - Initial configuring Glassfish with Let's Encrypt certificate", self.name)
                # Increased timeout as it restarts Glassfish
                SystemUtils.execute_command(["/bin/bash", str(configure_script)],
                    timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

                # Copy script to Let's Encrypt deploy hooks
                lets_encrypt_dir = self.config.get('initplan', 'lets_encrypt_dir', fallback="/etc/letsencrypt")
                deploy_hooks = pathlib.Path(lets_encrypt_dir, 'renewal-hooks', 'deploy')
                logger.info("%s - Copying %s to %s", self.name, configure_script, deploy_hooks)
                shutil.copy(configure_script, deploy_hooks)
            else:
                self._enable_start_glassfish()

        # Configure LDAP if required
        # Note: asadmin requires Glassfish to run and modifying the domain.xml directly is not supported
        if self.ldap_conf and not AsadminUtils.ldap_resource_created():
            logger.info("Configuring LDAP: %s", self.ldap_conf['jndiLookupName'])
            try:
                AsadminUtils.create_ldap_jndi_resource(self.ldap_conf['jndiLookupName'], self.ldap_conf['properties'])
            except Exception as e:
                self.friendly_name = str(e)
                raise Exception(self.friendly_name)
            SystemUtils.execute_command(["systemctl", "restart", "glassfish-domain1"],
                timeout=ConfigureGlassfish.GLASSFISH_START_TIMEOUT)

        if self.check_file:
            self.check_file.touch()
        
        return []

    def rollback(self) -> None:
        pass
